<?php

declare(strict_types=1);

namespace Drupal\search_api_exclude_lb;

use Drupal\Core\State\StateInterface;

/**
 * Default implementation of the helper.
 */
final class SearchApiExcludeLb implements SearchApiExcludeLbInterface {

  /**
   * Constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State service.
   */
  public function __construct(protected StateInterface $state) {}

  /**
   * {@inheritdoc}
   */
  public function getDebugMode(): bool {
    return $this->state->get(self::STATE_KEY, FALSE);
  }

  /**
   * {@inheritdoc}
   */
  public function setDebugMode(bool $debug_mode = FALSE): void {
    $this->state->set(self::STATE_KEY, $debug_mode);
  }

  /**
   * {@inheritdoc}
   */
  public static function getCacheTags(): array {
    return [self::STATE_KEY];
  }

  /**
   * {@inheritdoc}
   */
  public static function excludeByPluginId(array $plugin_ids, array &$plugin_definitions): void {
    foreach ($plugin_definitions as $id => &$definition) {
      if (in_array($id, $plugin_ids, TRUE)) {
        $definition['search_api_exclude_lb'] = TRUE;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function excludeByRegex(array $regex, array &$plugin_definitions): void {
    foreach ($plugin_definitions as $id => &$definition) {
      foreach ($regex as $expression) {
        if (preg_match($expression, $id)) {
          $definition['search_api_exclude_lb'] = TRUE;
          break;
        }
      }
    }
  }

}
