<?php

declare(strict_types=1);

namespace Drupal\search_api_exclude_lb;

/**
 * Defines our helper class.
 */
interface SearchApiExcludeLbInterface {

  /**
   * Our state key.
   *
   * @var string
   */
  public const STATE_KEY = 'search_api_exclude_lb';

  /**
   * Get debug mode state value.
   *
   * @return bool
   *   TRUE if debug mode is enabled.
   */
  public function getDebugMode(): bool;

  /**
   * Update the debug mode state.
   *
   * @param bool $debug_mode
   *   The new value. Defaults to FALSE.
   */
  public function setDebugMode(bool $debug_mode = FALSE): void;

  /**
   * Get cache tag(s) associated with the renders we want to affect.
   *
   * @return string[]
   *   The cache tag(s).
   */
  public static function getCacheTags(): array;

  /**
   * Flag given (Block) plugin IDs to be excluded from search indexing.
   *
   * @param string[] $plugin_ids
   *   The (Block) plugin IDs.
   * @param array<string, mixed> $plugin_definitions
   *   All (Block) plugin definitions.
   */
  public static function excludeByPluginId(array $plugin_ids, array &$plugin_definitions): void;

  /**
   * Flag (Block) plugin IDs matching regex to be excluded from search indexing.
   *
   * @param string[] $regex
   *   The regular expression.
   * @param array<string, mixed> $plugin_definitions
   *   All (Block) plugin definitions.
   */
  public static function excludeByRegex(array $regex, array &$plugin_definitions): void;

}
